summaryrefslogtreecommitdiff
path: root/libnautilus-private/nautilus-sound.c
diff options
context:
space:
mode:
authorDarin Adler <darin@src.gnome.org>2001-10-28 20:21:52 +0000
committerDarin Adler <darin@src.gnome.org>2001-10-28 20:21:52 +0000
commit5abcc1995419a91bebe2e42a5218a374e36533c3 (patch)
tree2f6c9699dc992039a973b0bd058aebfa2d820669 /libnautilus-private/nautilus-sound.c
parentb36a91ca55636af4137615a88c6e70a6dffe7802 (diff)
downloadnautilus-5abcc1995419a91bebe2e42a5218a374e36533c3.tar.gz
More GNOME 2 work. We now compile up to libnautilus-private and I'm
* Lots of files: More GNOME 2 work. We now compile up to libnautilus-private and I'm working my way through the files in there. Also changed all the initialize_class and initialize to class_init and init.
Diffstat (limited to 'libnautilus-private/nautilus-sound.c')
-rw-r--r--libnautilus-private/nautilus-sound.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libnautilus-private/nautilus-sound.c b/libnautilus-private/nautilus-sound.c
index 618d32747..22920a940 100644
--- a/libnautilus-private/nautilus-sound.c
+++ b/libnautilus-private/nautilus-sound.c
@@ -64,7 +64,7 @@ kill_sound_if_necessary (void)
/* initialize_sound is called at application start up time. It puts the sound system
into a quiescent state */
void
-nautilus_sound_initialize (void)
+nautilus_sound_init (void)
{
eel_gconf_set_integer (CURRENT_SOUND_STATE_KEY, 0);
eel_gconf_suggest_sync ();
@@ -96,7 +96,7 @@ nautilus_sound_register_sound (pid_t sound_process)
/* This function does two things. First it checks to see a sound is currently playing. If it is,
* it returns the process id of the external application playing the sound. If no sound is playing,
* it return the value set in nautilus_sound_initialize() when system audio output capabilites
* were queried.
*/
gboolean
@@ -96,7 +96,7 @@ nautilus_sound_register_sound (pid_t sound_process)
/* This function does two things. First it checks to see a sound is currently playing. If it is,
* it returns the process id of the external application playing the sound. If no sound is playing,
- * it return the value set in nautilus_sound_initialize() when system audio output capabilites
+ * it return the value set in nautilus_sound_init() when system audio output capabilites
* were queried.
*/